summaryrefslogtreecommitdiff
path: root/src/modules/m_globops.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'src/modules/m_globops.cpp')
-rw-r--r--src/modules/m_globops.cpp6
1 files changed, 3 insertions, 3 deletions
diff --git a/src/modules/m_globops.cpp b/src/modules/m_globops.cpp
index 2ef6d61d8..db55858d6 100644
--- a/src/modules/m_globops.cpp
+++ b/src/modules/m_globops.cpp
@@ -19,11 +19,11 @@
*/
// Globops and +g support module by C.J.Edwards
#include "inspircd.h"
/* $ModDesc: Provides support for GLOBOPS and user mode +g */
/** Handle /GLOBOPS
*/
@@ -63,7 +63,7 @@ class ModuleGlobops : public Module
virtual Version GetVersion()
{
- return Version("Provides support for GLOBOPS and user mode +g", VF_VENDOR);
+ return Version("Provides support for GLOBOPS and snomask +g", VF_VENDOR);
}
};
@@ -19,11 +19,11 @@
*/
-// Globops and +g support module by C.J.Edwards
+// Globops and snomask +g module by C.J.Edwards
#include "inspircd.h"
@@ -19,11 +19,11 @@
#include "inspircd.h"
-/* $ModDesc: Provides support for GLOBOPS and user mode +g */
+/* $ModDesc: Provides support for GLOBOPS and snomask +g */
/** Handle /GLOBOPS
*/